@@ -133,6 +133,17 @@ def tokenize_tweets(data):
 		sample_data_tokenized.append(tokenizer.tokenize(tweets.lower()))
 	return sample_data_tokenized
 	
+def define_hashtags(data):
+	hashtags=[]
+	for i in range(len(data)):
+		h= (re.findall(r"#(\w+)", data.text.iloc[i]))
+		t=[]
+		for i in range(len(h)):
+			t.append('#'+h[i].lower())
+		hashtags.append(t)
+	data['hashtags']=hashtags
+	return data
+	
 def keyword_score(data,sample_data_tokenized, keyword_corpus):
 	scores = []
 	for i in range(len(sample_data_tokenized)):
@@ -150,6 +161,7 @@ def keyword_score(data,sample_data_tokenized, keyword_corpus):
 
 def hashtag_score(data, hastags_corpus):
 	scores=[]
+	data = define_hashtags(data)
 	for hshtgs in data.hashtags:
 		score = 0
 		for h in hshtgs:
@@ -157,7 +169,7 @@ def hashtag_score(data, hastags_corpus):
 			for H in hastags_corpus.hashtags:
 				if h == H:
 					score += 1
-    scores.append(score)
+		scores.append(score)
 	data['hashtag_score'] = scores
 	data['index'] = [i for i in range(len(data))]
 	data['names']= ['TWEET '+str(i) for i in range(len(data))]
@@ -953,12 +965,23 @@ def NLP_analysis(data, keyword_corpus, hashtag_corpus):
 	tweets_df = sentiental_analysis_features(tweets_df)
 	sample_data_tokenized = tokenize_tweets(tweets_df)
 	tweets_df = keyword_score(tweets_df, sample_data_tokenized,keyword_corpus)
-	tweets_df = hashtag_score(tweets_df, sample_data_tokenized,hashtag_corpus)	
+	tweets_df = hashtag_score(tweets_df,hashtag_corpus)	
 	tweets_df["terrorist_suggestion"] = 0
 	tweets_df["terrorist_suggestion"][(tweets_df["hashtag_score"]>0) | (tweets_df["keyword_score"]>0)] = 1
-	data["per_hash_key"] = len(tweets_df[tweets_df["terrorist_suggestion"]==1]) / len(tweets_df)
-	tweets_df["terrorist_suggestion"][(tweets_df["terrorist_suggestion"]==1) & (tweets_df["polarity"] < -0.1) & (tweets_df["subjectivity"]>0.6)]= 2
-	data["per_terr_hash_key"] = len(tweets_df[tweets_df["terrorist_suggestion"]==2]) / len(tweets_df[tweets_df["terrorist_suggestion"]==1])
+	if len(tweets_df[tweets_df["terrorist_suggestion"]==1]) == 0:
+		data["per_hash_key"] = 0
+		data["per_terr_hash_key"] = 0
+	else:
+		data["per_hash_key"] = (len(tweets_df[tweets_df["terrorist_suggestion"]==1]) / len(tweets_df))
+		tweets_df["terrorist_suggestion"][(tweets_df["terrorist_suggestion"]==1) & (tweets_df["polarity"] < -0.1) & (tweets_df["subjectivity"]>0.6)]= 2
+		if len(tweets_df[tweets_df["terrorist_suggestion"]==2]) == 0:
+			data["per_terr_hash_key"] = 0
+		else:
+			print(tweets_df.groupby("terrorist_suggestion").size())
+			if len(tweets_df[tweets_df["terrorist_suggestion"]==1]) == 0:
+				data["per_terr_hash_key"] =1
+			else:
+				data["per_terr_hash_key"] = (len(tweets_df[tweets_df["terrorist_suggestion"]==2]) / len(tweets_df[tweets_df["terrorist_suggestion"]==1]))
 	data["suggestion"] = "No terrorist"
 	if(data["per_terr_hash_key"] >0.7) & (data["per_hash_key"]>0.15):
 		data["suggestion"]="Terrorist"
